@@ -25,6 +25,12 @@ use crate::errors::{KeyPairError, SignatureError};
 use std::fmt::Debug;
 use std::ops::MulAssign;
 
+#[cfg(not(feature = "std"))]
+use alloc::fmt::Display;
+
+#[cfg(feature = "std")]
+use std::fmt::Display;
+
 #[cfg(not(feature = "std"))]
 use alloc::fmt::Debug;
 
@@ -560,6 +566,12 @@ impl Debug for PublicKey {
     }
 }
 
+impl Display for PublicKey {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.write_str(&hex::encode(self.to_vec()))
+    }
+}
+
 #[derive(Debug, Clone, Copy, PartialEq)]
 pub struct Signature(schnorrkel::Signature);
 impl SignatureTrait for Signature {}
@@ -593,7 +605,8 @@ impl Len for Signature {
 
 /// A Diffie-Hellman shared secret derived from an `EphemeralSecretKey`
 /// and the other party's `PublicKey`.
-pub struct SharedSecret(RistrettoPoint);
+#[derive(Clone, Zeroize)]
+pub struct SharedSecret(#[zeroize(skip)] RistrettoPoint);
 impl SharedSecretKey for SharedSecret {}
 
 impl From<SharedSecret> for [u8; 32] {
@@ -711,6 +724,12 @@ pub struct EphemeralPublicKey(#[zeroize(skip)] schnorrkel::PublicKey);
 
 impl PublicKeyTrait for EphemeralPublicKey {}
 
+impl Display for EphemeralPublicKey {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.write_str(&hex::encode(self.to_vec()))
+    }
+}
+
 impl From<PublicKey> for EphemeralPublicKey {
     fn from(ik: PublicKey) -> Self {
         Self(ik.0)
